#include "Brick.h"

BrickWall::Brick::Brick(ShapeRect & rect, Color c)
	:
	rect(rect),
	colour(c)
{
}

void BrickWall::Brick::Draw(Graphics & gfx) const
{
	if(active)
	{
		gfx.DrawRect(rect.GetExpanded(-padding), colour);
	}
}

bool BrickWall::Brick::BallCollision(Ball & ball)
{
	bool collided = false;
	if(active && rect.Overlap(ball.GetRect()))
	{
		ball.ReboundY();
		active = false;
		collided = true;
	}
	return collided;
}

void BrickWall::Init(Vector2 & offset)
{
	int index = 0;
	for(int y = 0; y < numBricksDown; ++y)
	{
		const Color colour = colours[y];
		for(int x = 0; x < numBricksDown; ++x)
		{
			ShapeRect rect = ShapeRect(Vector2(x * width, y * height) + offset, width, height);
			bricks[index] = Brick(rect, colour);
			++index;
		}
	}
}

void BrickWall::Draw(Graphics & gfx) const
{
	for(Brick brick : bricks)
	{
		brick.Draw(gfx);
	}
}

void BrickWall::BallCollision(Ball & ball)
{
	for(Brick brick : bricks)
	{
		if(brick.BallCollision(ball))
		{
			soundBrick.Play();
			break;
		}
	}
}
