/******************************************************************************************
 *	Chili DirectX Framework Version 16.07.20											  *
 *	Game.h																				  *
 *	Copyright 2016 PlanetChili.net <http://www.planetchili.net>							  *
 *																						  *
 *	This file is part of The Chili DirectX Framework.									  *
 *																						  *
 *	The Chili DirectX Framework is free software: you can redistribute it and/or modify	  *
 *	it under the terms of the GNU General Public License as published by				  *
 *	the Free Software Foundation, either version 3 of the License, or					  *
 *	(at your option) any later version.													  *
 *																						  *
 *	The Chili DirectX Framework is distributed in the hope that it will be useful,		  *
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of						  *
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the						  *
 *	GNU General Public License for more details.										  *
 *																						  *
 *	You should have received a copy of the GNU General Public License					  *
 *	along with The Chili DirectX Framework.  If not, see <http://www.gnu.org/licenses/>.  *
 ******************************************************************************************/
#pragma once

#include "Keyboard.h"
#include "Mouse.h"
#include "Graphics.h"
#include "Sound.h"
#include "FrameTimer.h"
#include "Vector2.h"
#include "ShapeRect.h"
#include "Ball.h"
#include "Paddle.h"
#include "Brick.h"

class Game
{
public:
	Game(class MainWindow& wnd);
	Game(const Game&) = delete;
	Game& operator=(const Game&) = delete;
	void Go();

private:
	void ComposeFrame();
	void UpdateModel();

private:
	MainWindow& wnd;
	Graphics gfx;
	Sound soundPad = Sound(L"Sounds\\arkpad.wav");
	Sound soundBrick = Sound(L"Sounds\\arkbrick.wav");
	FrameTimer ft;
	ShapeRect frame = ShapeRect(Vector2(20.0f, 20.0f), 760.0f, 560.0f);
	Ball ball;
	Paddle paddle;

	static constexpr float padding = 2.0f;
	static constexpr int numBricksAcross = 12;
	static constexpr int numBricksDown = 5;
	static constexpr int numBricks = numBricksAcross * numBricksDown;
	static constexpr float width = 42.0f;
	static constexpr float height = 18.0f;
	Brick bricks[numBricks];
	
	Color colours[5] =
	{
		Color(44, 158, 176),
		Color(65, 168, 185),
		Color(86, 179, 195),
		Color(107, 189, 204),
		Color(128, 200, 214),
	};
};