#include "Paddle.h"

Paddle::Paddle(const Vector2& initPos)
	:
	position(initPos)
{
}

void Paddle::Draw(Graphics & gfx) const
{
	ShapeRect rect = GetRect();
	gfx.DrawRect(rect, Color(255, 10, 10));	
	rect.left += wingWidth;
	rect.right -= wingWidth;
	gfx.DrawRect(rect, Color(255, 255, 255));
}

void Paddle::Update(Keyboard& kbd, float deltaTime)
{
	if(kbd.KeyIsPressed(VK_LEFT))
	{
		position.x -= xVelocity * deltaTime;
	}
	if(kbd.KeyIsPressed(VK_RIGHT))
	{
		position.x += xVelocity * deltaTime;
	}
}

void Paddle::WallCollision(const ShapeRect & target)
{
	ShapeRect rect = GetRect();
	if(rect.left < target.left)
	{
		position.x += (target.left - rect.left);
	}
	else if(rect.right > target.right)
	{
		position.x += (target.right - rect.right);
	}
}

bool Paddle::BallCollision(Ball & ball) const
{
	bool collided = false;
	ShapeRect rect = GetRect();
	if(rect.Overlap(ball.GetRect()))
	{
		ball.ReboundY();
		collided = true;
	}
	return collided;
}

ShapeRect Paddle::GetRect() const
{
	Vector2 pos = position;
	return ShapeRect(pos, width / 2, height / 2, '0');
}
